Module: Observ::AgentSelectable

Extended by:
ActiveSupport::Concern
Defined in:
app/models/concerns/observ/agent_selectable.rb

Overview

Interface contract for agents that can be selected in the Observ UI This module defines the required methods that any selectable agent must implement

Usage:

class MyAgent < BaseAgent
include Observ::AgentSelectable

def self.display_name
  "My Custom Agent"
end

def self.description
  "Description of what this agent does"
end
end